      implicit none
c
c         total prob. of compton effect 
c
#include "Zglobalc.h"
#include "ZbasicCnst.h"
#include "Zmedia.h"
#include "Zmass.h"
#include "ZBPgene.h"

      character*40  file
      integer io, result

      real*8  Eg
      real*8  tprob, p


      io = 10

      call cerrorMsg(
     * "Enter media file path( such as"//
     *  " '../../Data/Media/Pb' )", 1)

      file= '../../Data/Media/Pb'

      read( *, * ) file

      call copenf(io, file, result)

      if( result .eq. 0 ) then

         call epReadTab(io, media)

         write(*,*) "#  'prob. of Compton'"
         write(*,*)
     *    "#  'Eg(MeV)'  ' /r.l' '/(g/cm2)' '/cm' 'mb/atom'"
         Eg = 0.1d-3            !  100 keV.
         do while ( Eg .lt. 101.d-2)   ! to 1GeV
            call epcompp(media, Eg, tprob, p) ! tprob is prob/r.l
            write(*, *) sngl(Eg*1000.d0), 
     *       sngl(tprob), sngl(tprob/media.X0g),
     *       sngl(tprob/media.X0), sngl(tprob/media.mbtoPX0)
            Eg = Eg * 10.0d0**(0.025d0)
         enddo
      else
         write(0,*) ' media file error '
      endif
      end
